@@ -29,13 +29,13 @@ import (
 
 const (
 	APPLICATION_NAME        = "Zabbix Agent"
-	ZABBIX_REVDATE          = "27 January 2025"
+	ZABBIX_REVDATE          = "20 May 2025"
 	ZABBIX_VERSION_MAJOR    = 5
 	ZABBIX_VERSION_MINOR    = 0
-	ZABBIX_VERSION_PATCH    = 46
+	ZABBIX_VERSION_PATCH    = 47
 	ZABBIX_VERSION_RC       = ""
 	ZABBIX_VERSION_RC_NUM   = "1400"
-	ZABBIX_VERSION_REVISION = "fa00329e313"
+	ZABBIX_VERSION_REVISION = "aa70cf76311"
 	copyrightMessage        = "Copyright (C) 2025 Zabbix SIA\n" +
 		"License GPLv2+: GNU GPL version 2 or later <https://www.gnu.org/licenses/>.\n" +
 		"This is free software: you are free to change and redistribute it according to\n" +
