@@ -1389,9 +1389,10 @@ int	zbx_tcp_accept(zbx_socket_t *s, unsigned int tls_accept)
 	fd_set		sock_set;
 	ZBX_SOCKET	accepted_socket;
 	ZBX_SOCKLEN_T	nlen;
-	int		i, n = 0, ret = FAIL;
+	int		i, n = 0, ret = FAIL, num_fds;
 	ssize_t		res;
 	unsigned char	buf;	/* 1 byte buffer */
+	struct timeval	tv = {1, 0};
 
 	zbx_tcp_unaccept(s);
 
@@ -1406,7 +1407,12 @@ int	zbx_tcp_accept(zbx_socket_t *s, unsigned int tls_accept)
 #endif
 	}
 
-	if (ZBX_PROTO_ERROR == select(n + 1, &sock_set, NULL, NULL, NULL))
+	if (0 == (num_fds = select(n + 1, &sock_set, NULL, NULL, &tv)))
+	{
+		ret = TIMEOUT_ERROR;
+		goto out;
+	}
+	else if (ZBX_PROTO_ERROR == num_fds)
 	{
 		zbx_set_socket_strerror("select() failed: %s", strerror_from_system(zbx_socket_last_error()));
 		return ret;
